@@ -1,6 +1,6 @@
 /***************************************************************************
     begin       : Thu Jan 31 2019
-    copyright   : (C) 2019 by Martin Preuss
+    copyright   : (C) 2025 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -16,7 +16,7 @@
 #include "aqhbci/joblayer/job_l.h"
 
 
-AH_JOB *AH_Job_GetAccountSepaInfo_new(AB_PROVIDER *pro, AB_USER *u, AB_ACCOUNT *acc);
+AH_JOB *AH_Job_GetAccountSepaInfo_new(AB_PROVIDER *pro, AB_USER *u);
 
 
 
