@@ -157,6 +157,27 @@ const AH_VOP_RESULT *AH_VopResult_List_GetByIbanAndName(const AH_VOP_RESULT_LIST
 
 
 
+int AH_VopResult_List_HasOnlyMatches(const AH_VOP_RESULT_LIST *vrList)
+{
+  if (vrList) {
+    const AH_VOP_RESULT *vr;
+
+    vr=AH_VopResult_List_First(vrList);
+    while(vr) {
+      int code;
+
+      code=AH_VopResult_GetResult(vr);
+      if (code!=AH_VopResultCodeMatch)
+        return 0;
+      vr=AH_VopResult_List_Next(vr);
+    }
+  }
+
+  return 1;
+}
+
+
+
 int AH_VopResultCode_fromString(const char *sResult)
 {
   if (strcasecmp(sResult, "RCVC")==0)
@@ -191,6 +212,21 @@ const char *AH_VopResultCode_toString(int i)
 
 
 
+const char *AH_VopResultCode_toGuiString(int i)
+{
+  switch(i) {
+  case AH_VopResultCodeNone:         return I18N("none");
+  case AH_VopResultCodeMatch:        return I18N("match");
+  case AH_VopResultCodeCloseMatch:   return I18N("close match");
+  case AH_VopResultCodeNoMatch:      return I18N("no match");
+  case AH_VopResultCodeNotAvailable: return I18N("not available");
+  case AH_VopResultCodePending:      return I18N("pending");
+  default:                           return I18N("none");
+  }
+}
+
+
+
 void AH_VopResult_Log(const AH_VOP_RESULT *vr, const char *logDomain, GWEN_LOGGER_LEVEL lv)
 {
   if (vr) {
